94057c3d3e
PR Test (NPU) / check-changes (push) Has been cancelled
PR Test (NPU) / pr-gate (push) Has been cancelled
PR Test (NPU) / set-image-config (push) Has been cancelled
PR Test (NPU) / stage-b-test-1-npu-a2 (0) (push) Has been cancelled
PR Test (NPU) / stage-b-test-1-npu-a2 (1) (push) Has been cancelled
PR Test (NPU) / stage-b-test-2-npu-a2 (0) (push) Has been cancelled
PR Test (NPU) / stage-b-test-2-npu-a2 (1) (push) Has been cancelled
PR Test (NPU) / stage-b-test-4-npu-a3 (push) Has been cancelled
PR Test (NPU) / stage-b-test-16-npu-a3 (push) Has been cancelled
PR Test (NPU) / multimodal-gen-test-1-npu-a3 (push) Has been cancelled
PR Test (NPU) / multimodal-gen-test-2-npu-a3 (push) Has been cancelled
PR Test (Arm64) / pr-gate (push) Has been cancelled
PR Test (Arm64) / check-changes (push) Has been cancelled
PR Test (Arm64) / build-test (push) Has been cancelled
PR Test (sgl-router) / gate (push) Has been cancelled
PR Test (sgl-router) / tier-1 — lint (push) Has been cancelled
PR Test (sgl-router) / tier-2 — build + test (push) Has been cancelled
PR Test (sgl-router) / tier-3 — docker (placeholder) (push) Has been cancelled
PR Test (sgl-router) / tier-3 — k8s integration (push) Has been cancelled
PR Test (sgl-router) / tier-3 — e2e (push) Has been cancelled
PR Test (sgl-router) / finish (push) Has been cancelled
PR Test (NPU) / single-node-poc (map[name:qwen3_6_27b_w8a8_1p_in64k_out1k_50ms runner:linux-aarch64-a3-2 test_case:test/registered/ascend/performance/qwen3_6_27b/test_npu_qwen3_6_27b_w8a8_1p_in64k_out1k_50ms.py test_type:perf]) (push) Has been cancelled
PR Test (NPU) / pr-test-npu-finish (push) Has been cancelled
PR Test (Xeon) / pr-gate (push) Has been cancelled
PR Test (Xeon) / check-changes (push) Has been cancelled
PR Test (Xeon) / build-test (, xeon-gnr, base-b-test-cpu) (push) Has been cancelled
PR Test (XPU) / check-changes (push) Has been cancelled
PR Test (XPU) / pr-gate (push) Has been cancelled
PR Test (XPU) / stage-a-test-1-gpu-xpu (push) Has been cancelled
PR Test (XPU) / wait-for-stage-a (push) Has been cancelled
PR Test (XPU) / stage-b-test-1-gpu-xpu (push) Has been cancelled
PR Test (XPU) / finish (push) Has been cancelled
CI Model Inventory / build-inventory (push) Has been cancelled
Lint / lint (push) Has been cancelled
PR Benchmark (SMG Components) / Benchmark Compilation Check (push) Has been cancelled
PR Benchmark (SMG Components) / Benchmark - Manual Policy (push) Has been cancelled
PR Benchmark (SMG Components) / Benchmark - Request Processing (push) Has been cancelled
PR Benchmark (SMG Components) / Benchmark Summary (push) Has been cancelled
PR Test (SMG) / build-wheel (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on windows (x86_64 - auto) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on macos (x86_64 - auto) (push) Has been cancelled
PR Test (SMG) / python-unit-tests (push) Has been cancelled
PR Test (SMG) / unit-tests (push) Has been cancelled
PR Test (SMG) / benchmarks (push) Has been cancelled
PR Test (SMG) / chat-completions (push) Has been cancelled
PR Test (SMG) / chat-completions-4gpu (push) Has been cancelled
PR Test (SMG) / e2e (push) Has been cancelled
PR Test (SMG) / docker-build-test (push) Has been cancelled
PR Test (SMG) / k8s-integration (push) Has been cancelled
PR Test (SMG) / finish (push) Has been cancelled
PR Test (SMG) / summarize-benchmarks (push) Has been cancelled
Release SGLang Model Gateway Docker Image / publish (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on macos (aarch64 - auto) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on linux (aarch64 - auto) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on linux (x86_64 - auto) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on linux (aarch64 - musllinux_1_1) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / build on linux (x86_64 - musllinux_1_1) (push) Has been cancelled
Release SGLang Model Gateway to PyPI / Build SDist (push) Has been cancelled
Release SGLang Model Gateway to PyPI / Upload to PyPI (push) Has been cancelled
Release SGLang Kernels / build-cu129-matrix (aarch64, 12.9, 3.10, arm-kernel-build-node) (push) Has been cancelled
Release SGLang Kernels / build-cu129-matrix (x86_64, 12.9, 3.10, x64-kernel-build-node) (push) Has been cancelled
Release SGLang Kernels / release-cu129 (push) Has been cancelled
Release SGLang Kernels / build-cu130-matrix (aarch64, 13.0, 3.10, arm-kernel-build-node) (push) Has been cancelled
Release SGLang Kernels / build-cu130-matrix (x86_64, 13.0, 3.10, x64-kernel-build-node) (push) Has been cancelled
Release SGLang Kernels / release-cu130 (push) Has been cancelled
Release SGLang Kernels / build-rocm-matrix (3.10, 700) (push) Has been cancelled
Release SGLang Kernels / build-rocm-matrix (3.10, 720) (push) Has been cancelled
Release SGLang Kernels / release-rocm700 (push) Has been cancelled
Release SGLang Kernels / release-rocm720 (push) Has been cancelled
Release SGLang Kernels / build-musa43 (43, 3.10) (push) Has been cancelled
Release SGLang Kernels / release-musa43 (push) Has been cancelled
84 lines
2.5 KiB
Python
84 lines
2.5 KiB
Python
import torch
|
|
import triton # type: ignore
|
|
import triton.language as tl # type: ignore
|
|
|
|
from sglang.kernel_api_logging import debug_kernel_api
|
|
from sglang.multimodal_gen.runtime.platforms import current_platform
|
|
from sglang.srt.utils.custom_op import register_custom_op
|
|
|
|
|
|
# Adapted from https://github.com/ModelTC/LightX2V/blob/main/lightx2v/common/ops/norm/triton_ops.py#L905-L956
|
|
@triton.jit
|
|
def _rms_norm_tiled_onepass(
|
|
y_ptr,
|
|
x_ptr,
|
|
w_ptr,
|
|
SEQ: tl.constexpr,
|
|
DIM: tl.constexpr,
|
|
EPS: tl.constexpr,
|
|
BLOCK_SIZE_SEQ: tl.constexpr,
|
|
BLOCK_SIZE_DIM: tl.constexpr,
|
|
):
|
|
seq_blk_id = tl.program_id(0)
|
|
seq_id = seq_blk_id * BLOCK_SIZE_SEQ
|
|
|
|
seq_offset = seq_id + tl.arange(0, BLOCK_SIZE_SEQ)[:, None]
|
|
s_mask = seq_offset < SEQ
|
|
d_offset = tl.arange(0, BLOCK_SIZE_DIM)[None, :]
|
|
d_mask = d_offset < DIM
|
|
y_blk = y_ptr + seq_offset * DIM + d_offset
|
|
x_blk = x_ptr + seq_offset * DIM + d_offset
|
|
mask = s_mask & d_mask
|
|
|
|
x = tl.load(x_blk, mask=mask, other=0.0).to(tl.float32)
|
|
mean_square = tl.sum(x * x, axis=1, keep_dims=True) / DIM
|
|
rstd = tl.math.rsqrt(mean_square + EPS)
|
|
w = tl.load(w_ptr + d_offset, mask=d_mask)
|
|
tl.store(y_blk, x * rstd * w, mask=mask)
|
|
|
|
|
|
@register_custom_op(op_name="triton_one_pass_rms_norm_cuda", out_shape="x")
|
|
def _triton_one_pass_rms_norm_cuda(
|
|
x: torch.Tensor, w: torch.Tensor, eps: float = 1e-6
|
|
) -> torch.Tensor:
|
|
shape = x.shape
|
|
x = x.contiguous()
|
|
y = torch.empty_like(x)
|
|
x_view = x.reshape(-1, shape[-1])
|
|
y_view = y.reshape(-1, shape[-1])
|
|
S, D = x_view.shape
|
|
|
|
block_size_seq = min(16, triton.next_power_of_2(max(1, S // 512)))
|
|
grid = (triton.cdiv(S, block_size_seq),)
|
|
|
|
with torch.get_device_module().device(x.device):
|
|
_rms_norm_tiled_onepass[grid](
|
|
y_view,
|
|
x_view,
|
|
w,
|
|
S,
|
|
D,
|
|
eps,
|
|
BLOCK_SIZE_DIM=triton.next_power_of_2(D),
|
|
BLOCK_SIZE_SEQ=block_size_seq,
|
|
)
|
|
return y
|
|
|
|
|
|
def triton_one_pass_rms_norm(x: torch.Tensor, w: torch.Tensor, eps: float = 1e-6):
|
|
return _triton_one_pass_rms_norm_cuda(x, w, eps)
|
|
|
|
|
|
if current_platform.is_mps():
|
|
from .mps_fallback import triton_one_pass_rms_norm_native
|
|
|
|
@debug_kernel_api
|
|
def triton_one_pass_rms_norm(x: torch.Tensor, w: torch.Tensor, eps: float = 1e-6):
|
|
return triton_one_pass_rms_norm_native(x, w, eps)
|
|
|
|
|
|
if current_platform.is_cpu():
|
|
from .torch_fallback import triton_one_pass_rms_norm_native
|
|
|
|
triton_one_pass_rms_norm = triton_one_pass_rms_norm_native
|